@@ -276,23 +276,20 @@ get_connections (GtkCList * imondlog_clist)
 				if (imond_versionnr > 10)
 				{
 					char in[128], out[128], buf[1024];
+					gfloat tmpflo;
 					char *inh = strtok (NULL, " ");
 					char *inl = strtok (NULL, " ");
 					char *outh = strtok (NULL, " ");
 					char *outl = strtok (NULL, " ");
 
-					/* reconstruct string ... >:-/ */
-					snprintf (buf, 1024, "%s %s %s %s",
-						  inh, inl, outh, outl);
-					get_bytes_64 (buf, in, out);
-					row[i++] = in;
-					row[i] = out;
-					ibytes +=
-						atoi (inh) * (2 ^ 32) +
-						atoi (inl);
-					obytes +=
-						atoi (outh) * (2 ^ 32) +
-						atoi (outl);
+					tmpflo = strtoul (inh,NULL,10) * pow(2.0,32.0) + strtoul (inl,NULL,10);
+					row[i++] = get_fbytes(tmpflo, ibytebuf);
+					ibytes += tmpflo;
+
+					tmpflo = strtoul (outh,NULL,10) * pow(2.0,32.0) + strtoul (outl,NULL,10);
+					row[i] = get_fbytes(tmpflo, obytebuf);
+					obytes += tmpflo;
+
 				}
 				else
 				{
@@ -337,10 +334,10 @@ get_connections (GtkCList * imondlog_clist)
 			    get_timestr (onltime, onl_time_buf));
 
 	gtk_label_set_text (GTK_LABEL (imondlog_ibytes_label),
-			    get_bytes (ibytes, ibytebuf));
+											get_fbytes(ibytes,ibytebuf));
 
 	gtk_label_set_text (GTK_LABEL (imondlog_obytes_label),
-			    get_bytes (obytes, obytebuf));
+											get_fbytes(obytes,obytebuf));
 
 	sprintf (chargebuf, "%d,%.2d", (charge / 100), (charge % 100));
 	gtk_label_set_text (GTK_LABEL (imondlog_charge_label), chargebuf);
@@ -468,6 +465,9 @@ imonc_init (gpointer window)
 
 	gf = gdk_font_load
 		("-b&h-lucida-medium-r-normal-*-10-*-*-*-p-*-iso8859-1");
+	if (!gf) // next try
+		gf = gdk_font_load
+			("-*-clean-medium-r-*-*-10-*-*-*-*-*-*-*");
 
 		/* first, create a GC to draw on */
 	gcb = gdk_gc_new (traffic_info->window);
@@ -691,7 +691,7 @@ imonc_init (gpointer window)
 
 	/* insert version nr. into about label */
   gtk_label_set_justify(GTK_LABEL(about_label), GTK_JUSTIFY_CENTER); /* fixing a glade bug */
- 	sprintf (about, "<big><b>GTK-Imonc</b></big>\nVersion %s\n\n© 2001-2004 by Stefan Strigler &lt;steve@zeank.in-berlin.de&gt;",VERSION);
+ 	sprintf (about, "<big><b>GTK-Imonc</b></big>\nVersion %s\n\n© 2001-2005 by Stefan Strigler &lt;steve@zeank.in-berlin.de&gt;",VERSION);
   gtk_label_set_markup (GTK_LABEL (about_label), about);
 
 
@@ -1329,11 +1329,12 @@ fli4l_reconnect (int signo)
 void
 get_bytes_64 (gchar * reply, gchar * in, gchar * out)
 {
-	guint64 outl, outh, inl, inh, num;
-	gchar buf[128];
+	unsigned long int outl, outh, inl, inh, num;
+	gchar buf[64];
 
 	outl = outh = inl = inh = 0;
 	num = sscanf (reply, "%lu %lu %lu %lu", &inh, &inl, &outh, &outl);
+
 	if (num != 4)
 	{
 		g_print("error while converting %s\n", reply);
@@ -1341,7 +1342,7 @@ get_bytes_64 (gchar * reply, gchar * in, gchar * out)
 	}
 	if (outh && outh != (unsigned long int) pow(2.0,32.0)-1)
 	{
-		snprintf (out, 64,"%luG+%s", (4 * outh), get_bytes (outl, buf));
+		snprintf (out, 64,"%luG+%s", (4 * outh), "hi");
 	}
 	else
 	{
@@ -1359,7 +1360,7 @@ get_bytes_64 (gchar * reply, gchar * in, gchar * out)
 
 
 gchar *
-get_bytes (guint64 bytes, gchar * buf)
+get_bytes (unsigned long int bytes, gchar * buf)
 {
 	gfloat flobytes;
 
@@ -1389,6 +1390,35 @@ get_bytes (guint64 bytes, gchar * buf)
 
 }				/* get_bytes (bytes, *buf) */
 
+gchar *
+get_fbytes (gfloat bytes, gchar * buf) {
+	gfloat flobytes;
+	if (bytes >= (1024 * 1024 * 1024))
+	{
+		flobytes = ((bytes / 1024.0) / 1024.0) / 1024.0;
+		snprintf (buf, 64,"%.2fG", flobytes);
+		return buf;
+	}
+
+	if (bytes >= (1024 * 1024))
+	{
+		flobytes = (bytes / 1024.0) / 1024.0;
+		snprintf (buf, 64,"%.2fM", flobytes);
+		return buf;
+	}
+
+	if (bytes >= 1024)
+	{
+		flobytes = bytes / 1024.0;
+		snprintf (buf, 64,"%.2fK", flobytes);
+		return buf;
+	}
+
+	snprintf (buf, 64, "%lu", (gulong) bytes);
+	return buf;
+
+}
+
 /* converts int representing seconds into a string in the format HH:MM:SS */
 gchar *
 get_timestr (gint time, gchar * buf)
@@ -1568,17 +1598,17 @@ traffic_info_update (gpointer window)
 			   buf);
 		if (k % 2 == 0)
 		{		/* download */
-			sprintf (d_buf, "D: %sB/s", buf);
+			sprintf (d_buf, "D:%sB/s", buf);
 			gdk_draw_text (widget->window, gf, gc[color], 2,
 				       baseline, d_buf, strlen (d_buf));
-			baseline += 12;
+			baseline += 12; // next line for next chan
 		}
 		else
 		{		/* upload */
-			sprintf (d_buf, "U: %sB/s", buf);
-			gdk_draw_text (widget->window, gf, gc[color],
-				       (traffic_info_width / 2) + 2, baseline,
-				       d_buf, strlen (d_buf));
+			sprintf (d_buf, "U:%sB/s", buf);
+ 			gdk_draw_text (widget->window, gf, gc[color],
+ 				       (traffic_info_width / 2) + 2, baseline,
+ 				       d_buf, strlen (d_buf));
 		}
 		color++;
 	}
@@ -1707,3 +1737,4 @@ gboolean fli4l_connect()
 
 	return TRUE;
 }
+
